@@ -172,7 +172,7 @@ UpdateResult        reactivateEvents(QVector<KAEvent>&, QVector<EventId>& inelig
 UpdateResult        enableEvents(QVector<KAEvent>&, bool enable, QWidget* msgParent = nullptr);
 QVector<KAEvent>    getSortedActiveEvents(QObject* parent, AlarmListModel** model = nullptr);
 void                purgeArchive(int purgeDays);    // must only be called from KAlarmApp::processQueue()
-void                displayKOrgUpdateError(QWidget* parent, UpdateError, UpdateResult korgError, int nAlarms = 0);
+void                displayKOrgUpdateError(QWidget* parent, UpdateError, const UpdateResult& korgError, int nAlarms = 0);
 Desktop             currentDesktopIdentity();
 QString             currentDesktopIdentityName();
 QStringList         checkRtcWakeConfig(bool checkEventExists = false);
@@ -182,8 +182,10 @@ bool                setRtcWakeTime(unsigned triggerTime, QWidget* parent);
 
 /** Return a prompt string to ask the user whether to convert the calendar to the
  *  current format.
- *  @param whole if true, the whole calendar needs to be converted; else only some
- *               alarms may need to be converted.
+ *  @param calendarName    The calendar name
+ *  @param calendarVersion The calendar version
+ *  @param whole           If true, the whole calendar needs to be converted; else
+ *                         only some alarms may need to be converted.
  */
 QString             conversionPrompt(const QString& calendarName, const QString& calendarVersion, bool whole);
 
